@@ -39,7 +39,6 @@ from .constants import (
     FileTransferType,
     QueryStatus,
 )
-from .description import CLIENT_NAME
 from .errorcode import (
     ER_CURSOR_IS_CLOSED,
     ER_FAILED_PROCESSING_PYFORMAT,
@@ -132,7 +131,7 @@ class ResultMetadata(NamedTuple):
             col["name"],
             FIELD_NAME_TO_ID[
                 col["extTypeName"].upper()
-                if "extTypeName" in col
+                if col.get("extTypeName")
                 else col["type"].upper()
             ],
             None,
@@ -399,7 +398,7 @@ class SnowflakeCursor:
                 return False
 
             with self._lock_canceling:
-                self.reset()
+                self.reset(closing=True)
                 self._connection = None
                 del self.messages[:]
                 return True
@@ -851,6 +850,11 @@ class SnowflakeCursor:
             self, self._query_result_format, data, self._description
         )
 
+        if not (is_dml or self.is_file_transfer):
+            logger.info(
+                "Number of results in first chunk: %s", result_chunks[0].rowcount
+            )
+
         self._result_set = ResultSet(
             self,
             result_chunks,
@@ -1175,15 +1179,18 @@ class SnowflakeCursor:
             },
         )
 
-    def reset(self):
+    def reset(self, closing=False):
         """Resets the result set."""
-        self._total_rowcount = -1  # reset the rowcount
+        # SNOW-647539: Do not erase the rowcount
+        # information when closing the cursor
+        if not closing:
+            self._total_rowcount = -1
         if self._result_state != ResultState.DEFAULT:
             self._result_state = ResultState.RESET
         if self._result is not None:
             self._result = None
         if self._inner_cursor is not None:
-            self._inner_cursor.reset()
+            self._inner_cursor.reset(closing=closing)
             self._result = None
             self._inner_cursor = None
         self._prefetch_hook = None
@@ -1208,15 +1215,19 @@ class SnowflakeCursor:
         self, telemetry_field: TelemetryField, value: Any
     ) -> None:
         """Builds an instance of TelemetryData with the given field and logs it."""
-        obj = {
-            "type": telemetry_field.value,
-            "source": self._connection.application if self._connection else CLIENT_NAME,
-            "query_id": self._sfqid,
-            "value": int(value),
-        }
         ts = get_time_millis()
         try:
-            self._connection._log_telemetry(TelemetryData(obj, ts))
+            self._connection._log_telemetry(
+                TelemetryData.from_telemetry_data_dict(
+                    from_dict={
+                        TelemetryField.KEY_TYPE.value: telemetry_field.value,
+                        TelemetryField.KEY_SFQID.value: self._sfqid,
+                        TelemetryField.KEY_VALUE.value: value,
+                    },
+                    timestamp=ts,
+                    connection=self._connection,
+                )
+            )
         except AttributeError:
             logger.warning(
                 "Cursor failed to log to telemetry. Connection object may be None.",
