@@ -22,6 +22,7 @@ from os import environ, path
 from os.path import expanduser
 from threading import Lock, RLock
 from time import gmtime, strftime
+from typing import Any
 
 import jwt
 
@@ -69,6 +70,7 @@ from snowflake.connector.time_util import DecorrelateJitterBackoff
 
 from . import constants
 from .cache import SFDictCache, SFDictFileCache
+from .telemetry import TelemetryField, generate_telemetry_data_dict
 
 try:
     OCSP_CACHE: SFDictFileCache[
@@ -218,20 +220,26 @@ class OCSPTelemetryData:
     def set_insecure_mode(self, insecure_mode):
         self.insecure_mode = insecure_mode
 
-    def generate_telemetry_data(self, event_type, urgent=False):
+    def generate_telemetry_data(
+        self, event_type: str, urgent: bool = False
+    ) -> dict[str, Any]:
         _, exception, _ = sys.exc_info()
-        telemetry_data = {}
-        telemetry_data.update({"eventType": event_type})
-        telemetry_data.update({"eventSubType": self.event_sub_type})
-        telemetry_data.update({"sfcPeerHost": self.sfc_peer_host})
-        telemetry_data.update({"certId": self.cert_id})
-        telemetry_data.update({"ocspRequestBase64": self.ocsp_req})
-        telemetry_data.update({"ocspResponderURL": self.ocsp_url})
-        telemetry_data.update({"errorMessage": self.error_msg})
-        telemetry_data.update({"insecureMode": self.insecure_mode})
-        telemetry_data.update({"failOpen": self.fail_open})
-        telemetry_data.update({"cacheEnabled": self.cache_enabled})
-        telemetry_data.update({"cacheHit": self.cache_hit})
+        telemetry_data = generate_telemetry_data_dict(
+            from_dict={
+                TelemetryField.KEY_OOB_EVENT_TYPE.value: event_type,
+                TelemetryField.KEY_OOB_EVENT_SUB_TYPE.value: self.event_sub_type,
+                TelemetryField.KEY_OOB_SFC_PEER_HOST.value: self.sfc_peer_host,
+                TelemetryField.KEY_OOB_CERT_ID.value: self.cert_id,
+                TelemetryField.KEY_OOB_OCSP_REQUEST_BASE64.value: self.ocsp_req,
+                TelemetryField.KEY_OOB_OCSP_RESPONDER_URL.value: self.ocsp_url,
+                TelemetryField.KEY_OOB_ERROR_MESSAGE.value: self.error_msg,
+                TelemetryField.KEY_OOB_INSECURE_MODE.value: self.insecure_mode,
+                TelemetryField.KEY_OOB_FAIL_OPEN.value: self.fail_open,
+                TelemetryField.KEY_OOB_CACHE_ENABLED.value: self.cache_enabled,
+                TelemetryField.KEY_OOB_CACHE_HIT.value: self.cache_hit,
+            },
+            is_oob_telemetry=True,
+        )
 
         telemetry_client = TelemetryService.get_instance()
         telemetry_client.log_ocsp_exception(
